@@ -78,6 +78,7 @@ describe 'horizon' do
           'API_RESULT_LIMIT = 1000',
           'DROPDOWN_MAX_ITEMS = 30',
           'TIME_ZONE = "UTC"',
+          "            'handlers': ['file'],",
           'COMPRESS_OFFLINE = True',
           "FILE_UPLOAD_TEMP_DIR = '/tmp'",
           "OPENSTACK_HEAT_STACK = {",
@@ -105,7 +106,7 @@ describe 'horizon' do
           :keystone_default_role          => 'SwiftOperator',
           :keystone_url                   => 'https://keystone.example.com:4682',
           :ssl_no_verify                  => true,
-          :log_handler                    => 'syslog',
+          :log_handlers                   => ['console', 'syslog'],
           :log_level                      => 'DEBUG',
           :openstack_endpoint_type        => 'internalURL',
           :secondary_endpoint_type        => 'ANY-VALUE',
@@ -209,7 +210,7 @@ describe 'horizon' do
           "]",
           "DEFAULT_THEME = 'default'",
           "            'level': 'DEBUG',",
-          "            'handlers': ['syslog'],",
+          "            'handlers': ['console', 'syslog'],",
           "SESSION_TIMEOUT = 1800",
           'COMPRESS_OFFLINE = False',
           "FILE_UPLOAD_TEMP_DIR = '/var/spool/horizon'",
@@ -296,7 +297,7 @@ describe 'horizon' do
 
       it {
         is_expected.to contain_package('python-memcache').with(
-          :tag    => ['openstack', 'horizon-package'],
+          :tag    => ['openstack'],
           :name   => platforms_params[:memcache_package],
          )
       }
