@@ -1,9 +1,6 @@
 require 'puppetlabs_spec_helper/module_spec_helper'
 require 'shared_examples'
-
-require 'puppet-openstack_spec_helper/defaults'
-require 'rspec-puppet-facts'
-include RspecPuppetFacts
+require 'puppet-openstack_spec_helper/facts'
 
 RSpec.configure do |c|
   c.alias_it_should_behave_like_to :it_configures, 'configures'
